"""
Main application classes. Used to initialize the application.
"""
import sys

from PyQt5.QtWidgets import QApplication
from docker import DockerClient
from signal_dispatcher.signal_dispatcher import SignalDispatcher

from events_dock.components import Events
from events_dock.threads import EventsThread
from events_dock.utils import Config


class App:
    def __init__(self, client: DockerClient):
        self.__config = Config()
        self.__app = QApplication(sys.argv)
        self.__client = client
        self.__main_widget = Events(client)

    def run(self):
        self.__main_widget.show()

        events_thread = EventsThread(self.__client)
        events_thread.start(priority=1)
        SignalDispatcher.register_signal('docker_event', events_thread.docker_event)
        SignalDispatcher.register_handler('docker_event', self.__main_widget.on_event)

        SignalDispatcher.dispatch()

        self.__app.exec()

    @property
    def client(self):
        return self.__client



import json

from PyQt5.QtCore import QThread, pyqtSignal
from docker import DockerClient

from events_dock.mappers import EventMapper
from events_dock.models import Event


class EventsThread(QThread):
    """
    EventsThread is used to emit events on containers operations detected. This keeps the interface up to date with
    the changes behind.

    Attributes:
        :client (DockerClient): Docker client
        :docker_event (pyqtSignal): Signal that is emitted
    """
    docker_event = pyqtSignal(Event, name='docker_event')

    def __init__(self, client: DockerClient):
        """
        :param client (DockerClient):
        """
        super().__init__()
        self.client = client

    def run(self):
        events = self.client.events()

        for event in events:
            event = json.loads(event.decode('utf-8'))
            docker_event = EventMapper.map(event)
            self.docker_event.emit(docker_event)





import sys

import docker
from events_dock.app import App


def main(args=None):
    """The main routine."""
    if args is None:
        args = sys.argv[1:]

    app = App(docker.from_env())
    app.run()


if __name__ == "__main__":
    main()



import json

from PyQt5.QtCore import pyqtSignal

from events_dock.mappers import EventMapper
from events_dock.models import Event


class EventStreamHandler:
    docker_event = pyqtSignal(Event, name='docker_event')

    def handle(self, event_stream):
        for event in event_stream:
            event = json.loads(event.decode('utf-8'))
            event = EventMapper.map(event)
            self.docker_event.emit(event)
